@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "async-pixbuf-ops.h"
 #include "gth-pixbuf-op.h"
 #include "gthumb-window.h"
+#include "gthumb-stock.h"
 #include "pixbuf-utils.h"
 
 
@@ -107,7 +108,7 @@ apply_changes (DialogData *data,
 
 	if (preview) {
 		g_signal_connect (G_OBJECT (pixop),
-				  "done",
+				  "pixbuf_op_done",
 				  G_CALLBACK (preview_done_cb),
 				  data);
 		gth_pixbuf_op_start (pixop);
@@ -124,10 +125,6 @@ ok_cb (GtkWidget  *widget,
        DialogData *data)
 {
 	apply_changes (data, data->image, data->image, FALSE);
-	/*
-	image_viewer_set_pixbuf (data->viewer, data->image);
-	window_image_modified (data->window, TRUE);
-	*/
 	gtk_widget_destroy (data->dialog);
 }
 
@@ -222,6 +219,7 @@ dlg_hue_saturation (GThumbWindow *window)
 	GtkWidget  *cancel_button;
 	GtkWidget  *preview_button;
 	GtkWidget  *hbox;
+	GtkWidget  *reset_image;
 	GdkPixbuf  *image;
 	int         image_width, image_height;
 	int         preview_width, preview_height;
@@ -271,6 +269,9 @@ dlg_hue_saturation (GThumbWindow *window)
 
 	data->viewer = IMAGE_VIEWER (window->viewer);
 
+	reset_image = glade_xml_get_widget (data->gui, "hl_reset_image");
+	gtk_image_set_from_stock (GTK_IMAGE (reset_image), GTHUMB_STOCK_RESET, GTK_ICON_SIZE_MENU);
+
 	/**/
 
 	image = image_viewer_get_current_pixbuf (data->viewer);
@@ -279,17 +280,9 @@ dlg_hue_saturation (GThumbWindow *window)
 	image_width = gdk_pixbuf_get_width (image);
 	image_height = gdk_pixbuf_get_height (image);
 
-	if (image_width > PREVIEW_SIZE || image_height > PREVIEW_SIZE) {
-		double factor;
-
-		factor = MIN ((double) (PREVIEW_SIZE) / image_width, 
-			      (double) (PREVIEW_SIZE) / image_height);
-		preview_width  = MAX ((int) (factor * image_width), 1);
-		preview_height = MAX ((int) (factor * image_height), 1);
-	} else {
-		preview_width  = image_width;
-		preview_height = image_height;
-	}
+	preview_width  = image_width;
+	preview_height = image_height;
+	scale_keepping_ratio (&preview_width, &preview_height, PREVIEW_SIZE, PREVIEW_SIZE);
 	
 	data->orig_pixbuf = gdk_pixbuf_scale_simple (image, 
 						     preview_width, 
