@@ -30,20 +30,16 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
 
-#ifdef HAVE_LIBEXIF
-#include <exif-data.h>
-#include <exif-content.h>
-#include <exif-entry.h>
-#endif /* HAVE_LIBEXIF */
-
 #include "comments.h"
 #include "dlg-image-prop.h"
 #include "file-data.h"
 #include "gthumb-histogram.h"
 #include "gthumb-window.h"
+#include "gth-exif-data-viewer.h"
 #include "gtk-utils.h"
 #include "image-viewer.h"
 #include "main.h"
+#include "pixbuf-utils.h"
 #include "icons/pixbufs.h"
 
 
@@ -84,6 +80,9 @@ typedef struct {
 	GtkWidget    *i_location_label;
 	GtkWidget    *i_date_modified_label;
 
+	GtkWidget    *i_next_button;
+	GtkWidget    *i_prev_button;
+
 	GtkWidget    *image;
 
 	GtkWidget     *i_comment_textview;
@@ -91,8 +90,8 @@ typedef struct {
 	GtkWidget     *i_categories_label;
 
 #ifdef HAVE_LIBEXIF
-	GtkWidget     *i_exif_treeview;
-	GtkListStore  *i_exif_model;
+	GtkWidget     *i_exif_data_view;	
+	GtkWidget     *i_exif_data_container;
 #endif /* HAVE_LIBEXIF */
 
 	GtkWidget     *i_histogram_channel;
@@ -278,212 +277,6 @@ next_image_cb (GtkWidget    *widget,
 }
 
 
-#ifdef HAVE_LIBEXIF
-
-static ExifTag usefull_tags[] = {
-	EXIF_TAG_EXPOSURE_TIME,
-	EXIF_TAG_EXPOSURE_PROGRAM,
-	EXIF_TAG_EXPOSURE_MODE,
-	EXIF_TAG_EXPOSURE_BIAS_VALUE,
-	EXIF_TAG_FLASH,
-	EXIF_TAG_FLASH_ENERGY,
-	EXIF_TAG_SPECTRAL_SENSITIVITY,
-	EXIF_TAG_SHUTTER_SPEED_VALUE,
-	EXIF_TAG_APERTURE_VALUE,
-	EXIF_TAG_BRIGHTNESS_VALUE,
-	EXIF_TAG_LIGHT_SOURCE,
-	EXIF_TAG_FOCAL_LENGTH,
-	EXIF_TAG_WHITE_BALANCE,
-	EXIF_TAG_WHITE_POINT,
-	EXIF_TAG_DIGITAL_ZOOM_RATIO,
-	EXIF_TAG_SUBJECT_DISTANCE,
-	EXIF_TAG_SUBJECT_DISTANCE_RANGE,
-	EXIF_TAG_METERING_MODE,
-	EXIF_TAG_CONTRAST,
-	EXIF_TAG_SATURATION,
-	EXIF_TAG_SHARPNESS,
-	EXIF_TAG_FOCAL_LENGTH_IN_35MM_FILM,
-	EXIF_TAG_BATTERY_LEVEL,
-
-	0,
-
-	EXIF_TAG_DATE_TIME,
-	EXIF_TAG_DATE_TIME_ORIGINAL,
-	EXIF_TAG_DATE_TIME_DIGITIZED,
-	EXIF_TAG_ORIENTATION,
-	EXIF_TAG_BITS_PER_SAMPLE,
-	EXIF_TAG_SAMPLES_PER_PIXEL,
-	EXIF_TAG_COMPRESSION,
-	EXIF_TAG_DOCUMENT_NAME,
-	EXIF_TAG_IMAGE_DESCRIPTION,
-
-	0,
-
-	/*
-	EXIF_TAG_RELATED_IMAGE_WIDTH,
-	EXIF_TAG_RELATED_IMAGE_LENGTH,
-	*/
-	EXIF_TAG_IMAGE_WIDTH,
-	EXIF_TAG_IMAGE_LENGTH,
-	EXIF_TAG_PIXEL_X_DIMENSION,
-	EXIF_TAG_PIXEL_Y_DIMENSION,
-	EXIF_TAG_X_RESOLUTION,
-	EXIF_TAG_Y_RESOLUTION,
-	EXIF_TAG_RESOLUTION_UNIT,
-
-	0,
-
-	EXIF_TAG_ARTIST,
-	EXIF_TAG_COPYRIGHT,
-	/*
-	EXIF_TAG_MAKER_NOTE,
-	EXIF_TAG_USER_COMMENT,
-	*/
-	EXIF_TAG_SUBJECT_LOCATION,
-	EXIF_TAG_SCENE_TYPE,
-
-	0,
-
-	EXIF_TAG_MAKE,
-	EXIF_TAG_MODEL,
-	EXIF_TAG_MAX_APERTURE_VALUE,
-	EXIF_TAG_SENSING_METHOD,
-	EXIF_TAG_EXIF_VERSION,
-	EXIF_TAG_FOCAL_PLANE_X_RESOLUTION,
-	EXIF_TAG_FOCAL_PLANE_Y_RESOLUTION,
-	EXIF_TAG_FOCAL_PLANE_RESOLUTION_UNIT
-};
-
-
-static gboolean
-tag_is_present (GtkTreeModel *model,
-		const char   *tag_name)
-{
-	GtkTreeIter  iter;
-
-	if (tag_name == NULL)
-		return FALSE;
-
-	if (! gtk_tree_model_get_iter_first (model, &iter))
-		return FALSE;
-
-	do {
-		char *tag_name2;
-
-		gtk_tree_model_get (model,
-				    &iter,
-				    NAME_COLUMN, &tag_name2,
-				    -1);
-		if ((tag_name2 != NULL) && (strcmp (tag_name, tag_name2) == 0)) {
-			g_free (tag_name2);
-			return TRUE;
-		}
-
-		g_free (tag_name2);
-	} while (gtk_tree_model_iter_next (model, &iter));
-
-	return FALSE;
-}
-
-
-static ExifEntry *
-get_entry_from_tag (ExifData *edata,
-		    int       tag)
-{
-	int i, j;
-
-	for (i = 0; i < EXIF_IFD_COUNT; i++) {
-		ExifContent *content = edata->ifd[i];
-
-		if ((content == NULL) || (content->count == 0)) 
-			continue;
-
-		for (j = 0; j < content->count; j++) {
-			ExifEntry *e = content->entries[j];
-
-			if (! content->entries[j]) 
-				continue;
-
-			if (e->tag == tag)
-				return e;
-		}
-	}
-
-	return NULL;
-}
-
-
-static void
-update_exif_data (DialogData *data)
-{
-	ExifData     *edata;
-	unsigned int  i;
-	gboolean      date_added = FALSE;
-	gboolean      last_entry_is_void = TRUE;
-
-	gtk_list_store_clear (data->i_exif_model);
-	
-	edata = exif_data_new_from_file (data->window->image_path);
-
-	if (edata == NULL) 
-                return;
-
-	for (i = 0; i < G_N_ELEMENTS (usefull_tags); i++) {
-		ExifEntry   *e;
-		GtkTreeIter  iter;
-		char        *utf8_name;
-		char        *utf8_value;
-		
-		if ((usefull_tags[i] == 0) && ! last_entry_is_void) {
-			gtk_list_store_append (data->i_exif_model, &iter);
-			gtk_list_store_set (data->i_exif_model, &iter,
-					    NAME_COLUMN, "",
-					    VALUE_COLUMN, "",
-					    POS_COLUMN, i,
-					    -1);
-			last_entry_is_void = TRUE;
-			continue;
-		}
-
-		e = get_entry_from_tag (edata, usefull_tags[i]);
-		if (e == NULL)
-			continue;
-
-		utf8_name = g_locale_to_utf8 (exif_tag_get_name (e->tag), -1, 0, 0, 0);
-		if (tag_is_present (GTK_TREE_MODEL (data->i_exif_model), utf8_name)) {
-			g_free (utf8_name);
-			continue;
-		}
-
-		if ((e->tag == EXIF_TAG_DATE_TIME)
-		    || (e->tag == EXIF_TAG_DATE_TIME_ORIGINAL)
-		    || (e->tag == EXIF_TAG_DATE_TIME_DIGITIZED)) {
-			if (date_added) {
-				g_free (utf8_name);
-				continue;
-			} else
-				date_added = TRUE;
-		}
-		
-		gtk_list_store_append (data->i_exif_model, &iter);
-		utf8_value = g_locale_to_utf8 (exif_entry_get_value (e), -1, 0, 0, 0);
-		gtk_list_store_set (data->i_exif_model, &iter,
-				    NAME_COLUMN, utf8_name,
-				    VALUE_COLUMN, utf8_value,
-				    POS_COLUMN, i,
-				    -1);
-		g_free (utf8_name);
-		g_free (utf8_value);
-
-		last_entry_is_void = FALSE;
-	}
-
-	exif_data_unref (edata);
-}
-
-#endif /* HAVE_LIBEXIF */
-
-
 static void
 update_comment (DialogData *data)
 {
@@ -577,36 +370,6 @@ update_histogram (DialogData *data)
 }
 
 
-static gboolean
-scale_thumb (int *width, 
-	     int *height, 
-	     int  max_width, 
-	     int  max_height)
-{
-	gboolean modified;
-	float    max_w = max_width;
-	float    max_h = max_height;
-	float    w = *width;
-	float    h = *height;
-	float    factor;
-	int      new_width, new_height;
-
-	if ((*width < max_width - 1) && (*height < max_height - 1)) 
-		return FALSE;
-
-	factor = MIN (max_w / w, max_h / h);
-	new_width  = MAX ((int) (w * factor), 1);
-	new_height = MAX ((int) (h * factor), 1);
-	
-	modified = (new_width != *width) || (new_height != *height);
-
-	*width = new_width;
-	*height = new_height;
-
-	return modified;
-}
-
-
 static void
 update_general_info (DialogData *data)
 {
@@ -634,7 +397,7 @@ update_general_info (DialogData *data)
 		gtk_label_set_text (GTK_LABEL (data->i_location_label), "");
 		gtk_label_set_text (GTK_LABEL (data->i_date_modified_label), "");
 	} else {
-		utf8_name = g_locale_to_utf8 (file_name_from_path (window->image_path), -1, 0, 0, 0);
+		utf8_name = g_filename_to_utf8 (file_name_from_path (window->image_path), -1, 0, 0, 0);
 		gtk_label_set_text (GTK_LABEL (data->i_name_label), utf8_name);
 		g_free (utf8_name);
 		
@@ -666,7 +429,7 @@ update_general_info (DialogData *data)
 		/**/
 		
 		location = remove_level_from_path (window->image_path);
-		_gtk_label_set_locale_text (GTK_LABEL (data->i_location_label), location);
+		_gtk_label_set_filename_text (GTK_LABEL (data->i_location_label), location);
 		g_free (location);
 		
 		/**/
@@ -688,7 +451,7 @@ update_general_info (DialogData *data)
 		
 		width = gdk_pixbuf_get_width (pixbuf);
 		height = gdk_pixbuf_get_height (pixbuf);
-		scale_thumb (&width, &height, PREVIEW_SIZE, PREVIEW_SIZE); 
+		scale_keepping_ratio (&width, &height, PREVIEW_SIZE, PREVIEW_SIZE); 
 		
 		scaled = gdk_pixbuf_scale_simple (pixbuf, 
 						  width, 
@@ -728,7 +491,9 @@ update_notebook_page (DialogData *data,
 
 #ifdef HAVE_LIBEXIF
 	case IPROP_PAGE_EXIF:
-		update_exif_data (data);
+		gth_exif_data_viewer_update (GTH_EXIF_DATA_VIEWER (data->i_exif_data_view),
+					     data->window_viewer,
+					     data->window->image_path);
 		break;
 #endif /* HAVE_LIBEXIF */
 
@@ -755,7 +520,7 @@ i_notebook_switch_page_cb (GtkWidget       *widget,
 	if (data->closing)
 		return TRUE;
 
-	if ((page_num >= 0) && (page_num < IPROP_NUM_PAGES))
+	if (page_num < IPROP_NUM_PAGES)
 		update_notebook_page (data, page_num);
 
 	return FALSE;
@@ -769,13 +534,7 @@ dlg_image_prop_new (GThumbWindow *window)
 	DialogData        *data;
 	GtkWidget         *i_image_vbox;
 	GtkWidget         *i_close_button;
-	GtkWidget         *i_next_button;
-	GtkWidget         *i_prev_button;
 	GtkWidget         *i_field_label;
-#ifdef HAVE_LIBEXIF
-	GtkCellRenderer   *renderer;
-	GtkTreeViewColumn *column;
-#endif /* HAVE_LIBEXIF */
 	char              *label;
 
 	data = g_new0 (DialogData, 1);
@@ -812,15 +571,15 @@ dlg_image_prop_new (GThumbWindow *window)
 
 	i_image_vbox = glade_xml_get_widget (data->gui, "i_image_vbox");
 	i_close_button = glade_xml_get_widget (data->gui, "i_close_button");
-	i_next_button = glade_xml_get_widget (data->gui, "i_next_button");
-	i_prev_button = glade_xml_get_widget (data->gui, "i_prev_button");
+	data->i_next_button = glade_xml_get_widget (data->gui, "i_next_button");
+	data->i_prev_button = glade_xml_get_widget (data->gui, "i_prev_button");
 	data->i_notebook = glade_xml_get_widget (data->gui, "i_notebook");
 
 	data->i_comment_textview = glade_xml_get_widget (data->gui, "i_comment_textview");
 	data->i_categories_label = glade_xml_get_widget (data->gui, "i_categories_label");
 
 #ifdef HAVE_LIBEXIF
-	data->i_exif_treeview = glade_xml_get_widget (data->gui, "i_exif_treeview");
+	data->i_exif_data_container = glade_xml_get_widget (data->gui, "i_exif_data_container");
 #endif /* HAVE_LIBEXIF */
 
 	data->i_comment_textbuffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (data->i_comment_textview));
@@ -886,36 +645,9 @@ dlg_image_prop_new (GThumbWindow *window)
 	g_object_set_data (G_OBJECT (data->dialog), "dialog_data", data);
 
 #ifdef HAVE_LIBEXIF
-	data->i_exif_model = gtk_list_store_new (NUM_COLUMNS,
-						 G_TYPE_STRING, 
-						 G_TYPE_STRING,
-						 G_TYPE_INT);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (data->i_exif_treeview),
-				 GTK_TREE_MODEL (data->i_exif_model));
-	g_object_unref (data->i_exif_model);
-
-	/**/
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Field"),
-							   renderer,
-							   "text", NAME_COLUMN,
-							   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (data->i_exif_treeview),
-				     column);
-
-	/**/
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Value "),
-							   renderer,
-							   "text", VALUE_COLUMN,
-							   NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (data->i_exif_treeview),
-				     column);
-	
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (data->i_exif_model), POS_COLUMN, GTK_SORT_ASCENDING);
-
+	data->i_exif_data_view = gth_exif_data_viewer_new (FALSE);
+	gtk_container_add (GTK_CONTAINER (data->i_exif_data_container), 
+			   data->i_exif_data_view);
 #endif /* HAVE_LIBEXIF */
 
 	/* Set the signals handlers. */
@@ -933,11 +665,11 @@ dlg_image_prop_new (GThumbWindow *window)
 			  "delete_event",
 			  G_CALLBACK (dialog_delete_event_cb),
 			  data);
-	g_signal_connect (G_OBJECT (i_next_button), 
+	g_signal_connect (G_OBJECT (data->i_next_button), 
 			  "clicked",
 			  G_CALLBACK (next_image_cb),
 			  data);
-	g_signal_connect (G_OBJECT (i_prev_button), 
+	g_signal_connect (G_OBJECT (data->i_prev_button), 
 			  "clicked",
 			  G_CALLBACK (prev_image_cb),
 			  data);
@@ -972,6 +704,26 @@ dlg_image_prop_new (GThumbWindow *window)
 }
 
 
+static void
+update_buttons_sensitivity (DialogData *data)
+{
+	GThumbWindow *window;
+	int           image_pos;
+
+	window = data->window;
+
+	if (! image_viewer_is_void (IMAGE_VIEWER (window->viewer))
+	    && (window->image_path != NULL))
+		image_pos = gth_file_list_pos_from_path (window->file_list, 
+							 window->image_path);
+	else
+		image_pos = -1;
+
+	gtk_widget_set_sensitive (data->i_prev_button, image_pos > 0);
+	gtk_widget_set_sensitive (data->i_next_button, (image_pos != -1) && (image_pos < gth_file_view_get_images (window->file_list->view) - 1));
+}
+
+
 static void
 update_title (DialogData *data)
 {
@@ -983,11 +735,12 @@ update_title (DialogData *data)
 
 	if (window->image_path == NULL) 
 		gtk_window_set_title (GTK_WINDOW (data->dialog), "");
+
 	else {
 		char *utf8_name;
 		char *title;
 
-		utf8_name = g_locale_to_utf8 (file_name_from_path (window->image_path), -1, 0, 0, 0);
+		utf8_name = g_filename_to_utf8 (file_name_from_path (window->image_path), -1, 0, 0, 0);
 		title = g_strdup_printf (_("%s Properties"), utf8_name); 
 		gtk_window_set_title (GTK_WINDOW (data->dialog), title);
 		g_free (utf8_name);
@@ -1011,6 +764,7 @@ dlg_image_prop_update (GtkWidget *image_prop_dlg)
 		data->page_updated[i] = FALSE;
 
 	update_title (data);
+	update_buttons_sensitivity (data);
 	update_notebook_page (data, gtk_notebook_get_current_page (GTK_NOTEBOOK (data->i_notebook)));
 }
 
