@@ -75,38 +75,6 @@ open_with__destroy_cb (GtkWidget  *widget,
 }
 
 
-static gboolean
-exec_command (const char *application, 
-	      GList      *file_list)
-{
-        GString *command;
-        GList   *scan;
-	GError  *err = NULL;
-	gboolean error;
-
-	command = g_string_new ("");
-	g_string_append (command, application);
-        for (scan = file_list; scan; scan = scan->next) {
-		char *filename = scan->data;
-		char *e_filename;
-
-		g_string_append_c (command, ' ');
-		e_filename = shell_escape (filename);
-		g_string_append (command, e_filename);
-
-		g_free (e_filename);
-        }
-
-	error = (! g_spawn_command_line_async (command->str, &err) 
-		 || (err != NULL));
-	if (error)
-		_gtk_error_dialog_from_gerror_run (NULL, &err);
-	g_string_free (command, TRUE);
-
-	return ! error;
-}
-
-
 static void
 open_cb (GtkWidget *widget,
 	 gpointer   callback_data)
