@@ -105,7 +105,7 @@ typedef struct {
 	/**/
 
 	Camera              *camera;
-	gboolean             camera_setted;
+	gboolean             camera_setted, view_folder;
         GPContext           *context;
 	CameraAbilitiesList *abilities_list;
 	GPPortInfoList      *port_list;
@@ -166,6 +166,11 @@ destroy_cb (GtkWidget  *widget,
 
 	/**/
 
+	if (data->view_folder)
+		window_go_to_directory (data->window, data->local_folder);
+
+	/**/
+
 	g_free (data->progress_info);
 	g_free (data->msg_text);
 	g_free (data->local_folder);
@@ -1190,8 +1195,8 @@ delete_images__done (AsyncOperationData *aodata,
 
 	if (interrupted)
 		return;
-	
-	window_go_to_directory (data->window, data->local_folder);
+
+	data->view_folder = TRUE;
 
 	if (ImportPhotos) {
 		ImportPhotos = FALSE;
@@ -1505,6 +1510,7 @@ dlg_photo_importer (GThumbWindow *window)
 	GdkPixbuf    *mute_pixbuf;
 	char         *default_path;
 	char         *default_film_name;
+	GValue        value = {0, };
 
 	data = g_new0 (DialogData, 1);
 	data->window = window;
@@ -1573,6 +1579,14 @@ dlg_photo_importer (GThumbWindow *window)
 
 	/* Set widgets data. */
 
+	/* Make use of the new filechooser */
+
+	g_value_init (&value, G_TYPE_BOOLEAN);
+	g_value_set_boolean (&value, TRUE);
+	g_object_set_property (G_OBJECT (data->destination_fileentry), "use_filechooser", &value);
+
+	/**/
+
 	data->camera_present_pixbuf = gdk_pixbuf_new_from_file (GTHUMB_GLADEDIR "/" CAMERA_FILE, NULL);
 	mute_pixbuf = gdk_pixbuf_new_from_file (GTHUMB_GLADEDIR "/" MUTE_FILE, NULL);
 
