@@ -51,7 +51,7 @@ typedef enum {
 
 
 typedef enum {
-	MONITOR_EVENT_FILE_CREATED,
+	MONITOR_EVENT_FILE_CREATED = 0,
 	MONITOR_EVENT_FILE_DELETED,
 	MONITOR_EVENT_DIR_CREATED,
 	MONITOR_EVENT_DIR_DELETED,
